# Django App Generator – `base_aram`

Un package Python qui vous permet de **générer rapidement une app Django** avec une structure de base personnalisée.

Ce générateur vous permet de gagner du temps lors de la création d’applications Django, en créant automatiquement les fichiers essentiels comme `views.py`, `urls.py`, `models.py`, etc., à partir d’un modèle prédéfini.

---

## 🚀 Installation

Dans le dossier du projet :

```bash
pip install package-aram

generate-django-app package_aram
